package de.klawitter.android.widget;

import android.content.Context;
import android.util.AttributeSet;
import android.widget.Button;

/**
 * Example on how to extend an exisiting view class in order to
 * make it "griddable".
 * <ul>
 * <li>implement the inferface Griddable.
 * <li>obtaining data from XML layout can be done in the construcor
 * letting a GridLocation object parse the attribute set.
 * <li>you may add setters if you want to construct you Grid by other means. :)
 * But note that the data has be set before measure is being called on the
 * grid.
 * </ul>
 * @author <a href="mailto:info-android@klawitter.de">Holger Klawitter</a>
 */
public class GriddableButton extends Button implements Griddable {

	private GridLocation gridLocation = new GridLocation();
	
	public GriddableButton(Context context) {
		super(context);
	}

	public GriddableButton(Context context, AttributeSet attrs) {
		super(context, attrs);
		gridLocation.parse( attrs );
	}

	public GriddableButton(Context context, AttributeSet attrs, int defStyle) {
		super(context, attrs, defStyle);
		gridLocation.parse( attrs );
	}

	public GridLocation getGridLocation() { return gridLocation; }

}
